<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Copyright © 2011–%1 Markus Enzenberger</source>
        <translation>Copyright © 2011–%1 Markus Enzenberger</translation>
    </message>
    <message>
        <source>Computer opponent for the board game Blokus</source>
        <translation>Rival virtual para el juego de mesa Blokus</translation>
    </message>
    <message>
        <source>Pentobi %1</source>
        <extracomment>The argument is the application version.</extracomment>
        <translation>Pentobi %1</translation>
    </message>
</context>
<context>
    <name>AnalyzeDialog</name>
    <message>
        <source>Analysis speed:</source>
        <translation>Análisis de velocidad:</translation>
    </message>
    <message>
        <source>Fast</source>
        <translation>Rápido</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Slow</source>
        <translation>Lento</translation>
    </message>
</context>
<context>
    <name>AnalyzeGame</name>
    <message>
        <source>(No analysis)</source>
        <translation>(Sin análisis)</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Coordinates</source>
        <translation>Coordenadas</translation>
    </message>
    <message>
        <source>Show variations</source>
        <translation>Mostrar variaciones</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Blanco</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Negro</translation>
    </message>
    <message>
        <source>Colorblind light</source>
        <translation>Fondo blanco para daltónicos</translation>
    </message>
    <message>
        <source>Colorblind dark</source>
        <translation>Fondo negro para daltónicos</translation>
    </message>
    <message>
        <source>System</source>
        <extracomment>Name of theme using default system colors</extracomment>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Move marking:</source>
        <translation>Marcado de movimientos:</translation>
    </message>
    <message>
        <source>Last with dot</source>
        <translation>Último con punto</translation>
    </message>
    <message>
        <source>Last with number</source>
        <translation>Último con número</translation>
    </message>
    <message>
        <source>All with number</source>
        <translation>Todas con número</translation>
    </message>
    <message>
        <source>None</source>
        <extracomment>Move marking/None</extracomment>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation>Animaciones</translation>
    </message>
    <message>
        <source>Show comment:</source>
        <translation>Mostrar comentario:</translation>
    </message>
    <message>
        <source>Always</source>
        <extracomment>Show-comment mode</extracomment>
        <translation>Siempre</translation>
    </message>
    <message>
        <source>As needed</source>
        <extracomment>Show-comment mode</extracomment>
        <translation>Si es preciso</translation>
    </message>
    <message>
        <source>Never</source>
        <extracomment>Show-comment mode</extracomment>
        <translation>Nunca</translation>
    </message>
    <message>
        <source>Color theme:</source>
        <translation>Color del tema:</translation>
    </message>
    <message>
        <source>Move number</source>
        <extracomment>Check box in appearance dialog whether to show the move number in the status bar.</extracomment>
        <translation>Número de movimiento</translation>
    </message>
</context>
<context>
    <name>AsciiArtSaveDialog</name>
    <message>
        <source>Export ASCII Art</source>
        <translation>Exportar arte ASCII</translation>
    </message>
    <message>
        <source>Text files</source>
        <translation>Archivos de texto</translation>
    </message>
</context>
<context>
    <name>AsciiArtSaveDialogNative</name>
    <message>
        <source>Export ASCII Art</source>
        <translation>Exportar arte ASCII</translation>
    </message>
    <message>
        <source>Text files</source>
        <translation>Archivos de texto</translation>
    </message>
</context>
<context>
    <name>BoardContextMenu</name>
    <message>
        <source>Go to Move %1</source>
        <translation>Ir al movimiento %1</translation>
    </message>
    <message>
        <source>Move Annotation</source>
        <translation>Valoración del movimiento</translation>
    </message>
    <message>
        <source>Move Annotation (%1)</source>
        <extracomment>The argument is the annotation symbol for the current move</extracomment>
        <translation>Valoración del movimiento (%1)</translation>
    </message>
</context>
<context>
    <name>ButtonApply</name>
    <message>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
</context>
<context>
    <name>ButtonCancel</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>ButtonClose</name>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
</context>
<context>
    <name>ButtonOk</name>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>ComputerDialog</name>
    <message>
        <source>Computer plays:</source>
        <translation>La máquina juega con:</translation>
    </message>
    <message>
        <source>Level %1</source>
        <translation>Nivel %1</translation>
    </message>
</context>
<context>
    <name>DocbookReader</name>
    <message>
        <source>Previous</source>
        <extracomment>Go to previous page of user manual</extracomment>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Contents</source>
        <extracomment>Go to table of contents of user manual</extracomment>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>Next</source>
        <extracomment>Go to next page of user manual</extracomment>
        <translation>Siguiente</translation>
    </message>
</context>
<context>
    <name>ExportImageDialog</name>
    <message>
        <source>Image width:</source>
        <translation>Ancho de la imagen:</translation>
    </message>
</context>
<context>
    <name>GameInfoDialog</name>
    <message>
        <source>Player Blue/Red:</source>
        <translation>Jugador con azules/rojas:</translation>
    </message>
    <message>
        <source>Player Purple:</source>
        <translation>Jugador con moradas:</translation>
    </message>
    <message>
        <source>Player Green:</source>
        <translation>Jugador con verdes:</translation>
    </message>
    <message>
        <source>Player Blue:</source>
        <translation>Jugador con azules:</translation>
    </message>
    <message>
        <source>Player Yellow/Green:</source>
        <translation>Jugador con amarillas/verdes:</translation>
    </message>
    <message>
        <source>Player Orange:</source>
        <translation>Jugador con naranjas:</translation>
    </message>
    <message>
        <source>Player Yellow:</source>
        <translation>Jugador con amarillas:</translation>
    </message>
    <message>
        <source>Player Red:</source>
        <translation>Jugador con rojas:</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Fecha:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Tiempo:</translation>
    </message>
    <message>
        <source>Event:</source>
        <translation>Acción:</translation>
    </message>
    <message>
        <source>Round:</source>
        <translation>Ronda:</translation>
    </message>
</context>
<context>
    <name>GameModel</name>
    <message>
        <source>Purple wins with 1 point.</source>
        <translation>Moradas ganan con 1 punto.</translation>
    </message>
    <message>
        <source>Purple wins with %L1 points.</source>
        <translation>Moradas ganan con %L1 puntos.</translation>
    </message>
    <message>
        <source>Orange wins with 1 point.</source>
        <translation>Naranjas ganan con 1 punto.</translation>
    </message>
    <message>
        <source>Orange wins with %L1 points.</source>
        <translation>Naranjas ganan con %L1 puntos.</translation>
    </message>
    <message>
        <source>Game ends in a tie.</source>
        <translation>La partida acaba en empate.</translation>
    </message>
    <message>
        <source>Green wins with 1 point.</source>
        <translation>Verdes ganan con 1 punto.</translation>
    </message>
    <message>
        <source>Green wins with %L1 points.</source>
        <translation>Verdes ganan con %L1 puntos.</translation>
    </message>
    <message>
        <source>Blue wins with 1 point.</source>
        <translation>Azules ganan con 1 punto.</translation>
    </message>
    <message>
        <source>Blue wins with %L1 points.</source>
        <translation>Azules ganan con %L1 puntos.</translation>
    </message>
    <message>
        <source>Green wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Ganan verdes (empate resuelto).</translation>
    </message>
    <message>
        <source>Blue/Red wins with 1 point.</source>
        <translation>Azules/rojas ganan con 1 punto.</translation>
    </message>
    <message>
        <source>Blue/Red wins with %L1 points.</source>
        <translation>Azules/rojas ganan con %L1 puntos.</translation>
    </message>
    <message>
        <source>Yellow/Green wins with 1 point.</source>
        <translation>Amarillas/verdes ganan con 1 punto.</translation>
    </message>
    <message>
        <source>Yellow/Green wins with %L1 points.</source>
        <translation>Amarillas/verdes ganan con %L1 puntos.</translation>
    </message>
    <message>
        <source>Yellow/Green wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Ganan amarillas/verdes (empate resuelto).</translation>
    </message>
    <message>
        <source>Blue wins.</source>
        <translation>Azules ganan.</translation>
    </message>
    <message>
        <source>Yellow wins.</source>
        <translation>Amarillas ganan.</translation>
    </message>
    <message>
        <source>Red wins.</source>
        <translation>Rojas ganan.</translation>
    </message>
    <message>
        <source>Red wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Ganan rojas (empate resuelto).</translation>
    </message>
    <message>
        <source>Yellow wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Ganan amarillas (empate resuelto).</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue and Yellow.</source>
        <translation>La partida acaba con empate entre azules y amarillas.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue and Red.</source>
        <translation>La partida acaba con empate entre azules y rojas.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Yellow and Red.</source>
        <translation>La partida acaba con empate entre amarillas y rojas.</translation>
    </message>
    <message>
        <source>Game ends in a tie between all players.</source>
        <translation>La partida acaba con empate entre todos los jugadores.</translation>
    </message>
    <message>
        <source>Green wins.</source>
        <translation>Verdes ganan.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Yellow and Red.</source>
        <translation>La partida acaba con empate entre azules, amarillas y rojas.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Yellow and Green.</source>
        <translation>La partida acaba con empate entre azules, amarillas y verdes.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Red and Green.</source>
        <translation>La partida acaba con empate entre azules, rojas y verdes.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Yellow, Red and Green.</source>
        <translation>La partida acaba con empate entre amarillas, rojas y verdes.</translation>
    </message>
    <message>
        <source>Invalid Blokus SGF file. (%1)</source>
        <translation>Archivo SGF de Blokus no válido. (%1)</translation>
    </message>
    <message>
        <source>Clipboard is empty.</source>
        <translation>El portapapeles está vacío.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sin título</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <extracomment>The argument is a number, which will be increased if a file with the same name already exists</extracomment>
        <translation>Sin título %1</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nueva carpeta</translation>
    </message>
    <message>
        <source>New Folder %1</source>
        <extracomment>The argument is a number, which will be increased if a folder with the same name already exists</extracomment>
        <translation>Nueva carpeta %1</translation>
    </message>
    <message>
        <source>(Setup)</source>
        <translation>(Configuración)</translation>
    </message>
    <message>
        <source>(No moves)</source>
        <translation>(Sin movimientos)</translation>
    </message>
    <message>
        <source>Move %1</source>
        <extracomment>The argument is the current move number.</extracomment>
        <translation>Movimiento %1</translation>
    </message>
    <message>
        <source>Unsupported character set</source>
        <translation>Juego de caracteres no compatible</translation>
    </message>
</context>
<context>
    <name>GameVariantDialog</name>
    <message>
        <source>Classic</source>
        <translation>Clásico</translation>
    </message>
    <message>
        <source>Duo</source>
        <translation>Dúo</translation>
    </message>
    <message>
        <source>Junior</source>
        <translation>Sencillo</translation>
    </message>
    <message>
        <source>Trigon</source>
        <translation>Trigón</translation>
    </message>
    <message>
        <source>Nexos</source>
        <translation>Nexos</translation>
    </message>
    <message>
        <source>GembloQ</source>
        <translation>GembloQ</translation>
    </message>
    <message>
        <source>Callisto</source>
        <translation>Calisto</translation>
    </message>
    <message>
        <source>Players:</source>
        <translation>Jugadores:</translation>
    </message>
    <message>
        <source>Colors:</source>
        <translation>Colores:</translation>
    </message>
</context>
<context>
    <name>GameViewDesktop</name>
    <message>
        <source>Computer is thinking…</source>
        <translation>La máquina está pensando...</translation>
    </message>
    <message>
        <source>Running game analysis…</source>
        <translation>Realizando análisis de la partida...</translation>
    </message>
    <message>
        <source>Computer is thinking… (up to %1 seconds remaining)</source>
        <translation>La máquina está pensando... (queda un máximo de %1 segundos)</translation>
    </message>
    <message>
        <source>Computer is thinking… (up to %1 minutes remaining)</source>
        <translation>La máquina está pensando... (queda un máximo de %1 minutos)</translation>
    </message>
</context>
<context>
    <name>GotoMoveDialog</name>
    <message>
        <source>Move number:</source>
        <translation>Número de movimiento:</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>Pentobi Help</source>
        <translation>Ayuda para Pentobi</translation>
    </message>
</context>
<context>
    <name>ImageSaveDialog</name>
    <message>
        <source>Save Image</source>
        <translation>Guardar imagen</translation>
    </message>
    <message>
        <source>PNG image files</source>
        <translation>Archivos de imagen PNG</translation>
    </message>
    <message>
        <source>JPEG image files</source>
        <translation>Archivos de imagen JPEG</translation>
    </message>
</context>
<context>
    <name>ImageSaveDialogNative</name>
    <message>
        <source>Save Image</source>
        <translation>Guardar imagen</translation>
    </message>
    <message>
        <source>PNG image files</source>
        <translation>Archivos de imagen PNG</translation>
    </message>
    <message>
        <source>JPEG image files</source>
        <translation>Archivos de imagen JPEG</translation>
    </message>
</context>
<context>
    <name>InitialRatingDialog</name>
    <message>
        <source>Initialize your rating for this game variant.</source>
        <translation>Inicialice su nivel para esta variante de juego.</translation>
    </message>
    <message>
        <source>Initial rating:</source>
        <translation>Nivel inicial:</translation>
    </message>
    <message>
        <source>Beginner</source>
        <translation>Principiante</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Experto</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Pentobi</source>
        <extracomment>Window title if no file is loaded.</extracomment>
        <translation>Pentobi</translation>
    </message>
    <message>
        <source>Game analysis is only possible in main variation.</source>
        <translation>Solo se puede analizar la partida en la variación principal.</translation>
    </message>
    <message>
        <source>Autosaved game was changed by another instance of Pentobi. Overwrite?</source>
        <translation>Existe una partida guardada automáticamente que ha sido modificada por una nueva partida de Pentobi. ¿Desea sobrescribirla?</translation>
    </message>
    <message>
        <source>Your rating has increased from %1 to %2.</source>
        <translation>Su nivel ha subido de %1 a %2.</translation>
    </message>
    <message>
        <source>Your rating has decreased from %1 to %2.</source>
        <translation>Tu nivel ha descendido de %1 a %2.</translation>
    </message>
    <message>
        <source>Your rating stays at %1.</source>
        <translation>Su nivel sigue siendo %1.</translation>
    </message>
    <message>
        <source>Delete all rating information for the current game variant?</source>
        <translation>¿Desactivar la selección de nivel para la variante de juego actual?</translation>
    </message>
    <message>
        <source>Delete all variations?</source>
        <translation>¿Eliminar todas las variaciones?</translation>
    </message>
    <message>
        <source>Save failed.</source>
        <translation>Error al guardar.</translation>
    </message>
    <message>
        <source>End of tree was reached. Continue search from start of the tree?</source>
        <translation>Se ha alcanzado el final del árbol. ¿Desea continuar la búsqueda desde el inicio del árbol?</translation>
    </message>
    <message>
        <source>No comment found</source>
        <translation>No hay comentarios</translation>
    </message>
    <message>
        <source>%1 (modified)</source>
        <extracomment>Label for modified loaded game. The argument is the file name.</extracomment>
        <translation>%1 (modificado)</translation>
    </message>
    <message>
        <source>File has been modified by another application. Reload?</source>
        <translation>Otra aplicación ha modificado el archivo. ¿Desea volver a cargarlo?</translation>
    </message>
    <message>
        <source>Continue computer move?</source>
        <translation>¿Continuar con el movimiento de la máquina?</translation>
    </message>
    <message>
        <source>Keep only position?</source>
        <translation>¿Conservar solo posición?</translation>
    </message>
    <message>
        <source>Keep only subtree?</source>
        <translation>¿Conservar solo subárbol?</translation>
    </message>
    <message>
        <source>Open failed.</source>
        <translation>Error al abrir.</translation>
    </message>
    <message>
        <source>Start rated game with Purple against Pentobi level %1?</source>
        <translation>¿Comenzar partida con selección de nivel con moradas contra Pentobi nivel %1?</translation>
    </message>
    <message>
        <source>Start rated game with Green against Pentobi level %1?</source>
        <translation>¿Comenzar partida con selección de nivel con verdes contra Pentobi nivel %1?</translation>
    </message>
    <message>
        <source>Start rated game with Blue/Red against Pentobi level %1?</source>
        <translation>¿Comenzar partida con selección de nivel con azules/rojas contra Pentobi nivel %1?</translation>
    </message>
    <message>
        <source>Start rated game with Blue against Pentobi level %1?</source>
        <translation>¿Comenzar partida con selección de nivel con azules contra Pentobi nivel %1?</translation>
    </message>
    <message>
        <source>Start rated game with Orange against Pentobi level %1?</source>
        <translation>¿Comenzar partida con selección de nivel con naranjas contra Pentobi nivel %1?</translation>
    </message>
    <message>
        <source>Start rated game with Yellow/Green against Pentobi level %1?</source>
        <translation>¿Comenzar partida con selección de nivel con amarillas/verdes contra Pentobi nivel %1?</translation>
    </message>
    <message>
        <source>Start rated game with Yellow against Pentobi level %1?</source>
        <translation>¿Comenzar partida con selección de nivel con amarillas contra Pentobi nivel %1?</translation>
    </message>
    <message>
        <source>Start rated game with Red against Pentobi level %1?</source>
        <translation>¿Comenzar la partida con rojas, después de la selección de nivel, contra Pentobi nivel %1?</translation>
    </message>
    <message>
        <source>You have not yet played rated games in this game variant.</source>
        <translation>Todavía no ha jugado ninguna partida con selección de nivel en esta variante de juego.</translation>
    </message>
    <message>
        <source>Truncate this subtree?</source>
        <translation>¿Eliminar este subárbol?</translation>
    </message>
    <message>
        <source>Truncate children?</source>
        <translation>¿Eliminar descendientes?</translation>
    </message>
    <message>
        <source>Discard game?</source>
        <translation>¿Abandonar partida?</translation>
    </message>
    <message>
        <source>Pentobi %1 (level %2)</source>
        <extracomment>Player name for game info in rated game. First argument is version of Pentobi, second argument is level.</extracomment>
        <translation>Pentobi %1 (nivel %2)</translation>
    </message>
    <message>
        <source>Human</source>
        <extracomment>Player name for game info in rated game.</extracomment>
        <translation>Humano</translation>
    </message>
    <message>
        <source>Rated game</source>
        <translation>Partida con selección de nivel</translation>
    </message>
    <message>
        <source>File has been modified by another application. Overwrite?</source>
        <translation>Otra aplicación ha modificado el archivo. ¿Desea sobrescribirlo?</translation>
    </message>
    <message>
        <source>%1 - Pentobi</source>
        <extracomment>Window title if file is loaded. The argument is the file name prepended with a star if the file has been modified.</extracomment>
        <translation>%1 - Pentobi</translation>
    </message>
    <message>
        <source>Not enough memory</source>
        <translation>Memoria insuficiente</translation>
    </message>
    <message>
        <source>Game analysis aborted</source>
        <translation>Se ha anulado el análisis de la partida</translation>
    </message>
    <message>
        <source>Computer move aborted</source>
        <translation>Se ha anulado el movimiento de la máquina</translation>
    </message>
    <message>
        <source>Rating information deleted</source>
        <translation>La información sobre el nivel ha sido borrada</translation>
    </message>
    <message>
        <source>Variations deleted</source>
        <translation>Se han borrado las variaciones</translation>
    </message>
    <message>
        <source>File saved</source>
        <translation>Archivo guardado</translation>
    </message>
    <message>
        <source>Saving image failed or unsupported image format</source>
        <translation>Se ha producido un error al guardar la imagen o el formato de archivo de imagen no es compatible</translation>
    </message>
    <message>
        <source>Image saved</source>
        <translation>Se ha guardado la imagen</translation>
    </message>
    <message>
        <source>Creating image failed</source>
        <translation>Se ha producido un error al crear la imagen</translation>
    </message>
    <message>
        <source>Continuing rated game</source>
        <translation>Continuar partida con selección de nivel</translation>
    </message>
    <message>
        <source>Kept only position</source>
        <translation>Se ha conservado solo la posición</translation>
    </message>
    <message>
        <source>Kept only subtree</source>
        <translation>Se ha conservado solo el subárbol</translation>
    </message>
    <message>
        <source>Variation is now %1</source>
        <translation>La variación es ahora %1</translation>
    </message>
    <message>
        <source>Children truncated</source>
        <translation>Se han eliminado los descendientes</translation>
    </message>
    <message>
        <source>Setup</source>
        <extracomment>Small-screen label for setup mode (short for &quot;Setup Mode&quot;).</extracomment>
        <translation>Configuración</translation>
    </message>
    <message>
        <source>Setup Mode</source>
        <translation>Modo configuración</translation>
    </message>
    <message>
        <source>Rated</source>
        <extracomment>Label for ongoing rated game</extracomment>
        <translation>Nivel</translation>
    </message>
    <message>
        <source>Rated %1</source>
        <extracomment>Small-screen label for finished rated game (short for &quot;Rated Game&quot;). The argument is the game number.</extracomment>
        <translation>Nivel %1</translation>
    </message>
    <message>
        <source>Rated Game %1</source>
        <extracomment>Label for rated game. The argument is the game number.</extracomment>
        <translation>Partida con selección de nivel %1</translation>
    </message>
    <message>
        <source>Main Variation</source>
        <translation>Variación principal</translation>
    </message>
    <message>
        <source>Beginning of Branch</source>
        <translation>Inicio de la rama</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Comentario</translation>
    </message>
    <message>
        <source>Settings</source>
        <extracomment>Menu item Computer/Settings</extracomment>
        <translation>Ajustes</translation>
    </message>
    <message>
        <source>Find Move</source>
        <translation>Buscar movimiento</translation>
    </message>
    <message>
        <source>Next Comment</source>
        <translation>Siguiente comentario</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Game Info</source>
        <translation>Información de partida</translation>
    </message>
    <message>
        <source>Move Number…</source>
        <translation>Número de movimiento...</translation>
    </message>
    <message>
        <source>Pentobi Help</source>
        <translation>Ayuda para Pentobi</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nuevo</translation>
    </message>
    <message>
        <source>Rated Game</source>
        <translation>Partida con selección de nivel</translation>
    </message>
    <message>
        <source>Open…</source>
        <translation>Abrir...</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Jugar</translation>
    </message>
    <message>
        <source>Play Move</source>
        <extracomment>Play a single move</extracomment>
        <translation>Realizar movimiento</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Save As…</source>
        <translation>Guardar como...</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Undo Move</source>
        <translation>Deshacer movimiento</translation>
    </message>
    <message>
        <source>Blue/Red</source>
        <translation>Azul/rojo</translation>
    </message>
    <message>
        <source>Purple</source>
        <translation>Morado</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>Verde</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>Azul</translation>
    </message>
    <message>
        <source>Yellow/Green</source>
        <translation>Amarillo/Verde</translation>
    </message>
    <message>
        <source>Orange</source>
        <translation>Naranja</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>Amarillo</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>Rojo</translation>
    </message>
    <message>
        <source>Pentobi failed to generate a move.</source>
        <translation>Pentobi no pudo generar un movimiento.</translation>
    </message>
    <message>
        <source>Press back again to exit</source>
        <translation>Vuelva a presionar atrás para salir</translation>
    </message>
</context>
<context>
    <name>MenuComputer</name>
    <message>
        <source>Computer</source>
        <translation>Máquina</translation>
    </message>
</context>
<context>
    <name>MenuEdit</name>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Make Main Variation</source>
        <translation>Convertir en variación principal</translation>
    </message>
    <message>
        <source>Variation Up</source>
        <extracomment>Short for Move Variation Up</extracomment>
        <translation>Subir variación</translation>
    </message>
    <message>
        <source>Variation Down</source>
        <extracomment>Short for Move Variation Down</extracomment>
        <translation>Bajar variación</translation>
    </message>
    <message>
        <source>Delete Variations</source>
        <translation>Eliminar variaciones</translation>
    </message>
    <message>
        <source>Truncate</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Truncate Children</source>
        <translation>Eliminar descendientes</translation>
    </message>
    <message>
        <source>Keep Position</source>
        <translation>Conservar posición</translation>
    </message>
    <message>
        <source>Keep Subtree</source>
        <translation>Conservar subárbol</translation>
    </message>
    <message>
        <source>Setup Mode</source>
        <translation>Modo configuración</translation>
    </message>
    <message>
        <source>Next Color</source>
        <translation>Siguiente color</translation>
    </message>
    <message>
        <source>Annotation…</source>
        <translation>Valoración...</translation>
    </message>
    <message>
        <source>Made main variation</source>
        <translation>Se ha convertido en variación principal</translation>
    </message>
</context>
<context>
    <name>MenuExport</name>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Image…</source>
        <translation>Imagen...</translation>
    </message>
    <message>
        <source>ASCII Art…</source>
        <translation>Arte ASCII...</translation>
    </message>
</context>
<context>
    <name>MenuGame</name>
    <message>
        <source>Game</source>
        <translation>Partida</translation>
    </message>
    <message>
        <source>Game Variant…</source>
        <translation>Variante de juego...</translation>
    </message>
    <message>
        <source>Open Clipboard</source>
        <translation>Abrir portapapeles</translation>
    </message>
</context>
<context>
    <name>MenuGo</name>
    <message>
        <source>Go</source>
        <translation>Ir a</translation>
    </message>
</context>
<context>
    <name>MenuHelp</name>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>About Pentobi</source>
        <translation>Acerca de Pentobi</translation>
    </message>
</context>
<context>
    <name>MenuRecentFiles</name>
    <message>
        <source>Open Recent</source>
        <translation>Abrir reciente</translation>
    </message>
    <message>
        <source>Clear List</source>
        <extracomment>Menu item for clearing the recent files list</extracomment>
        <translation>Borrar lista</translation>
    </message>
</context>
<context>
    <name>MenuTools</name>
    <message>
        <source>Tools</source>
        <translation>Herramientas</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Selección de nivel</translation>
    </message>
    <message>
        <source>Clear Rating</source>
        <translation>Borrar nivel</translation>
    </message>
    <message>
        <source>Clear Analysis</source>
        <translation>Borrar análisis</translation>
    </message>
    <message>
        <source>Analyze Game…</source>
        <translation>Analizar partida...</translation>
    </message>
</context>
<context>
    <name>MenuView</name>
    <message>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barra de herramientas</translation>
    </message>
</context>
<context>
    <name>MoveAnnotationDialog</name>
    <message>
        <source>Move %1</source>
        <translation>Movimiento %1</translation>
    </message>
    <message>
        <source>Very good</source>
        <translation>Muy bueno</translation>
    </message>
    <message>
        <source>Good</source>
        <translation>Bueno</translation>
    </message>
    <message>
        <source>Interesting</source>
        <translation>Interesante</translation>
    </message>
    <message>
        <source>Doubtful</source>
        <translation>Indeciso</translation>
    </message>
    <message>
        <source>Bad</source>
        <translation>Malo</translation>
    </message>
    <message>
        <source>Very Bad</source>
        <translation>Muy mal</translation>
    </message>
    <message>
        <source>No annotation</source>
        <translation>Sin valoración</translation>
    </message>
</context>
<context>
    <name>NewFolderDialog</name>
    <message>
        <source>Folder name:</source>
        <translation>Nombre de la carpeta:</translation>
    </message>
</context>
<context>
    <name>OpenDialog</name>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Blokus games</source>
        <translation>Partidas de Blokus</translation>
    </message>
</context>
<context>
    <name>OpenDialogNative</name>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Blokus games</source>
        <translation>Partidas de Blokus</translation>
    </message>
</context>
<context>
    <name>PentobiFileDialog</name>
    <message>
        <source>Overwrite file?</source>
        <translation>¿Sobrescribir archivo?</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Todos los archivos</translation>
    </message>
</context>
<context>
    <name>PentobiMenuItem</name>
    <message>
        <source>Ctrl</source>
        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Shift</source>
        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
        <translation>Mayús</translation>
    </message>
</context>
<context>
    <name>PentobiToolBar</name>
    <message>
        <source>Start a new game</source>
        <translation>Comenzar una partida nueva</translation>
    </message>
    <message>
        <source>Start a rated game</source>
        <translation>Comenzar una partida con selección de nivel</translation>
    </message>
    <message>
        <source>Set the colors played by the computer</source>
        <translation>Elija los colores con los que jugará la máquina</translation>
    </message>
    <message>
        <source>Make the computer continue to play the current color</source>
        <translation>Haga que la máquina siga jugando con el color actual</translation>
    </message>
    <message>
        <source>Make the computer play the current color</source>
        <translation>Haga que la máquina juegue con el color actual</translation>
    </message>
    <message>
        <source>Go to beginning of game</source>
        <translation>Ir al inicio de la partida</translation>
    </message>
    <message>
        <source>Go ten moves backward</source>
        <translation>Retroceder diez movimientos</translation>
    </message>
    <message>
        <source>Go one move backward</source>
        <translation>Retroceder un movimiento</translation>
    </message>
    <message>
        <source>Go one move forward</source>
        <translation>Avanzar un movimiento</translation>
    </message>
    <message>
        <source>Go ten moves forward</source>
        <translation>Avanzar diez movimientos</translation>
    </message>
    <message>
        <source>Go to end of moves</source>
        <translation>Ir al final de los movimientos</translation>
    </message>
    <message>
        <source>Go to previous variation</source>
        <translation>Ir a la variación anterior</translation>
    </message>
    <message>
        <source>Go to next variation</source>
        <translation>Ir a la siguiente variación</translation>
    </message>
    <message>
        <source>Abort game analysis</source>
        <translation>Anular análisis de la partida</translation>
    </message>
    <message>
        <source>Abort computer move</source>
        <translation>Anular movimiento de la máquina</translation>
    </message>
    <message>
        <source>Undo move</source>
        <extracomment>Tooltip for Undo button</extracomment>
        <translation>Deshacer movimiento</translation>
    </message>
    <message>
        <source>Open menu</source>
        <translation>Abrir menú</translation>
    </message>
</context>
<context>
    <name>RatingDialog</name>
    <message>
        <source>Your rating:</source>
        <translation>Su nivel:</translation>
    </message>
    <message>
        <source>Game variant:</source>
        <translation>Variante de juego:</translation>
    </message>
    <message>
        <source>Classic (2)</source>
        <extracomment>Short for Classic (2 players)</extracomment>
        <translation>Clásico (2)</translation>
    </message>
    <message>
        <source>Classic (3)</source>
        <extracomment>Short for Classic (3 players)</extracomment>
        <translation>Clásico (3)</translation>
    </message>
    <message>
        <source>Classic (4)</source>
        <extracomment>Short for Classic (4 players)</extracomment>
        <translation>Clásico (4)</translation>
    </message>
    <message>
        <source>Duo</source>
        <translation>Dúo</translation>
    </message>
    <message>
        <source>Junior</source>
        <translation>Sencillo</translation>
    </message>
    <message>
        <source>Trigon (2)</source>
        <extracomment>Short for Trigon (2 players)</extracomment>
        <translation>Trigón (2)</translation>
    </message>
    <message>
        <source>Trigon (3)</source>
        <extracomment>Short for Trigon (3 players)</extracomment>
        <translation>Trigón (3)</translation>
    </message>
    <message>
        <source>Trigon (4)</source>
        <extracomment>Short for Trigon (4 players)</extracomment>
        <translation>Trigón (4)</translation>
    </message>
    <message>
        <source>Nexos (2)</source>
        <extracomment>Short for Nexos (2 players)</extracomment>
        <translation>Nexos (2)</translation>
    </message>
    <message>
        <source>Nexos (4)</source>
        <extracomment>Short for Nexos (4 players)</extracomment>
        <translation>Nexos (4)</translation>
    </message>
    <message>
        <source>Callisto (2)</source>
        <extracomment>Short for Callisto (2 players, 2 colors)</extracomment>
        <translation>Calisto (2)</translation>
    </message>
    <message>
        <source>Callisto (2/4)</source>
        <extracomment>Short for Callisto (2 players, 4 colors)</extracomment>
        <translation>Calisto (2/4)</translation>
    </message>
    <message>
        <source>Callisto (3)</source>
        <extracomment>Short for Callisto (3 players)</extracomment>
        <translation>Calisto (3)</translation>
    </message>
    <message>
        <source>Callisto (4)</source>
        <extracomment>Short for Callisto (4 players)</extracomment>
        <translation>Calisto (4)</translation>
    </message>
    <message>
        <source>GembloQ (4)</source>
        <extracomment>Short for GembloQ (4 players)</extracomment>
        <translation>GembloQ (4)</translation>
    </message>
    <message>
        <source>GembloQ (2)</source>
        <extracomment>Short for GembloQ (2 players, 2 colors)</extracomment>
        <translation>GembloQ (2)</translation>
    </message>
    <message>
        <source>GembloQ (2/4)</source>
        <extracomment>Short for GembloQ (2 players, 4 colors)</extracomment>
        <translation>GembloQ (2/4)</translation>
    </message>
    <message>
        <source>GembloQ (3)</source>
        <extracomment>Short for GembloQ (3 players)</extracomment>
        <translation>GembloQ (3)</translation>
    </message>
    <message>
        <source>Rated games:</source>
        <translation>Partidas con selección de nivel:</translation>
    </message>
    <message>
        <source>Best previous rating:</source>
        <translation>Mejor nivel anterior:</translation>
    </message>
    <message>
        <source>Recent development:</source>
        <translation>Novedad reciente:</translation>
    </message>
    <message>
        <source>Open Game %1</source>
        <translation>Abrir partida %1</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Blokus games</source>
        <translation>Partidas de Blokus</translation>
    </message>
</context>
<context>
    <name>SaveDialogNative</name>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Blokus games</source>
        <translation>Partidas de Blokus</translation>
    </message>
</context>
<context>
    <name>TableModel</name>
    <message>
        <source>Game</source>
        <extracomment>Table header for game number in rating dialog</extracomment>
        <translation>Partida</translation>
    </message>
    <message>
        <source>Result</source>
        <extracomment>Table header for game result in rating dialog</extracomment>
        <translation>Resultado</translation>
    </message>
    <message>
        <source>Level</source>
        <extracomment>Table header for level in rating dialog</extracomment>
        <translation>Nivel</translation>
    </message>
    <message>
        <source>Your Color</source>
        <extracomment>Table header for player color(s) in rating dialog</extracomment>
        <translation>Su color</translation>
    </message>
    <message>
        <source>Date</source>
        <extracomment>Table header for game date in rating dialog</extracomment>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>Win</source>
        <extracomment>Result of rated game is a win</extracomment>
        <translation>Victoria</translation>
    </message>
    <message>
        <source>Loss</source>
        <extracomment>Result of rated game is a loss</extracomment>
        <translation>Derrota</translation>
    </message>
    <message>
        <source>Tie</source>
        <extracomment>Result of rated game is a tie. Abbreviate long translations to ensure that all columns of rated games list are visible on mobile devices with small screens.</extracomment>
        <translation>Empate</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>computer opponent for the board game Blokus</source>
        <translation>rival virtual para el juego de mesa Blokus</translation>
    </message>
    <message>
        <source>Set maximum level to &lt;n&gt;.</source>
        <extracomment>Description for command line option --maxlevel</extracomment>
        <translation>Establecer nivel máximo en &lt;n&gt;.</translation>
    </message>
    <message>
        <source>Do not use opening books.</source>
        <extracomment>Description for command line option --nobook</extracomment>
        <translation>No utilizar abrir libros.</translation>
    </message>
    <message>
        <source>Use layout optimized for smartphones.</source>
        <extracomment>Description for command line option --mobile</extracomment>
        <translation>Utilizar el diseño optimizado para móviles.</translation>
    </message>
    <message>
        <source>Do not delay fast computer moves.</source>
        <extracomment>Description for command line option --nodelay</extracomment>
        <translation>No ralentizar los movimientos rápidos de la máquina.</translation>
    </message>
    <message>
        <source>Set random seed to &lt;n&gt;.</source>
        <extracomment>Description for command line option --seed</extracomment>
        <translation>Establecer valor de inicialización aleatorio en &lt;n&gt;.</translation>
    </message>
    <message>
        <source>Use &lt;n&gt; threads (0=auto).</source>
        <extracomment>Description for command line option --threads</extracomment>
        <translation>Usar &lt;n&gt; subprocesos (0=auto).</translation>
    </message>
    <message>
        <source>Print logging information to standard error.</source>
        <extracomment>Description for command line option --verbose</extracomment>
        <translation>Imprimir información de registro sobre el error típico.</translation>
    </message>
    <message>
        <source>file.blksgf</source>
        <extracomment>Name of command line argument.</extracomment>
        <translation>file.blksgf</translation>
    </message>
    <message>
        <source>Blokus SGF file to open (optional).</source>
        <translation>Abrir archivo SGF de Blokus (opcional).</translation>
    </message>
    <message>
        <source>--maxlevel must be between 1 and %1</source>
        <translation>--nivel máximo debe estar entre 1 y %1</translation>
    </message>
    <message>
        <source>--seed must be a positive number</source>
        <translation>--el valor de inicialización tiene que ser un número positivo</translation>
    </message>
    <message>
        <source>--threads must be a positive number</source>
        <translation>--los subprocesos tienen que tener un valor positivo</translation>
    </message>
    <message>
        <source>Too many arguments</source>
        <translation>Demasiados argumentos</translation>
    </message>
</context>
</TS>